@@ -1,3 +1,11 @@
+class MyClass(object):
+    def __init__(self, a, b):
+        self.a = a
+        self.b = b
+        self._b = [b]
+
+mc = MyClass(15, MyClass(12, None))
+
 
 def simple_func(x):
     x += 1
@@ -20,6 +28,7 @@ def simple_func(x):
 
     return 2*x
 
+
 def fermat(n):
     """Returns triplets of the form x^n + y^n = z^n.
     Warning! Untested with n > 2.
