@@ -44,7 +44,8 @@ class InspectInfo(object):
         self.display_type = CONFIG["stringifier"]
         self.highlighted = False
         self.repeated_at_top = False
-        self.show_private_members = False
+        self.access_level = "public"
+        self.show_methods = False
         self.wrap = CONFIG["wrap_variables"]
 
 
@@ -286,6 +287,17 @@ class ValueWalker:
                 displayed_value = type_stringifier(value) \
                                 + " (!! %s error !!)" % iinfo.display_type
 
+            if iinfo.show_detail:
+                if iinfo.access_level == "public":
+                    marker = "pub"
+                elif iinfo.access_level == "private":
+                    marker = "pri"
+                else:
+                    marker = "all"
+                if iinfo.show_methods:
+                    marker += "+()"
+                displayed_value += " [%s]" % marker
+
             self.add_item(prefix, label,
                 displayed_value, id_path, attr_prefix)
 
@@ -311,24 +323,29 @@ class ValueWalker:
 
             # containers --------------------------------------------------
             key_it = None
+
             try:
-                l = len(value)
+                if PY3:
+                    key_it = value.keys()
+                else:
+                    key_it = value.iterkeys()
             except:
                 pass
-            else:
+
+            if key_it is None:
                 try:
-                    value[0]
-                except IndexError:
-                    key_it = []
+                    l = len(value)
                 except:
                     pass
                 else:
-                    key_it = xrange(l)
-
-            try:
-                key_it = value.iterkeys()
-            except:
-                pass
+                    try:
+                        value[0]
+                    except IndexError:
+                        key_it = []
+                    except:
+                        pass
+                    else:
+                        key_it = xrange(l)
 
             if key_it is not None:
                 cnt = 0
@@ -361,15 +378,23 @@ class ValueWalker:
                     for key in ki]
             keys.sort()
 
-            cnt_omitted = 0
+            cnt_omitted_private = cnt_omitted_methods = 0
 
             for key in keys:
-                if key[0] == "_" and not iinfo.show_private_members:
-                    cnt_omitted += 1
-                    continue
+                if iinfo.access_level == "public":
+                    if key.startswith("_"):
+                        cnt_omitted_private += 1
+                        continue
+                elif iinfo.access_level == "private":
+                    if key.startswith("__") and key.endswith("__"):
+                        cnt_omitted_private += 1
+                        continue
 
                 try:
                     attr_value = getattr(value, key)
+                    if callable(attr_value) and not iinfo.show_methods:
+                        cnt_omitted_methods += 1
+                        continue
                 except:
                     attr_value = WatchEvalError()
 
@@ -378,11 +403,13 @@ class ValueWalker:
                         "%s.%s" % (id_path, key))
 
             if not keys:
-                if cnt_omitted:
-                    self.add_item(prefix+self.PREFIX,
-                            "<omitted private attributes>", None)
+                if cnt_omitted_private:
+                    label = "<omitted private attributes>"
+                elif cnt_omitted_methods:
+                    label = "<omitted methods>"
                 else:
-                    self.add_item(prefix+self.PREFIX, "<empty>", None)
+                    label = "<empty>"
+                self.add_item(prefix+self.PREFIX, label, None)
 
             if not key_its:
                 self.add_item(prefix+self.PREFIX, "<?>", None)
